<!DOCTYPE html>


<h2>SSH Client Framework</h2>

<h1></h1>

<h4>This framework is to be used for DevOps, Infrastructure As Code and Network Automation projects.</h4>

<p></p>

<p></p>


<h3>Advantages:</h3>
<h4>Simple, Fast and Secure method to:</h4>
<ul>
    <li>Create automated tools to <strong>Rename HP Switches interfaces connected to Cisco Access-Points</strong></li>
    <li>Create automated tools to <strong>Rename Cisco Access-Points interfaces that are connected to HP Switches</strong></li>
</ul>

<h1></h1>


<p>How to use the framework.</p>

<h3>Example 1</h3>
<h4>To rename the:</h4>
<ol>
    <li>"pip install juraHP" in your machine</li>
    <li>"from juraHP import robot"</li>
    <li>robot.run_rename()</li>
</ol>


<p></p>

<h1></h1>


<p>For support: Please contact david.johnnes@gmail.com.</p>

<h1></h1>


